==> ejc-mdm-api-3.0.0-20220512.025245-58-sources.jar: com/ejianc/foundation/mdm/vo/DataModelItemVO.java <==
package com.ejianc.foundation.mdm.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 数据模型字段表
 * 
 * @author guoming
 *
 */
public class DataModelItemVO extends BaseVO {

	private static final long serialVersionUID = 1L;

	/**
	 * 数据模型ID
	 */
	private Long dataModelId;
	/**
	 * 模型字段编码
	 */
	private String itemCode;
	/**
	 * 模型字段名称
	 */
	private String itemName;
	/**
	 * 数据类型
	 */
	private String dataType;
	/**
	 * 数据长度
	 */
	private Integer dataLength;
	/**
	 * 小数位
	 */
	private Integer decimalPlace;
	/**
	 * 是否唯一： 0不唯一，1：唯一
	 */
	private Boolean uniqueFlag;
	/**
	 * 是否必填：0不必填 ，1必填
	 */
	private Boolean mustFillFlag;

	/**
	 * 参照编码
	 */
	private String referCode;

	/**
	 * 枚举档案编码
	 */
	private String defdocCode;
	/**
	 * 是否作为查询条件：0不作为，1作为查询条件
	 */
	private Boolean queryConditionFlag;
	/**
	 * 排序字段
	 */
	private Integer sequence;

	/**
	 * 描述信息
	 */
	private String description;

	public Long getDataModelId() {
		return dataModelId;
	}

	public void setDataModelId(Long dataModelId) {
		this.dataModelId = dataModelId;
	}

	public String getItemCode() {
		return itemCode;
	}

	public void setItemCode(String itemCode) {
		this.itemCode = itemCode;
	}

	public String getItemName() {
		return itemName;
	}

	public void setItemName(String itemName) {
		this.itemName = itemName;
	}

	public String getDataType() {
		return dataType;
	}

	public void setDataType(String dataType) {
		this.dataType = dataType;
	}

	public Integer getDataLength() {
		return dataLength;
	}

	public void setDataLength(Integer dataLength) {
		this.dataLength = dataLength;
	}

	public Integer getDecimalPlace() {
		return decimalPlace;
	}

	public void setDecimalPlace(Integer decimalPlace) {
		this.decimalPlace = decimalPlace;
	}

	public Boolean getUniqueFlag() {
		return uniqueFlag;
	}

	public void setUniqueFlag(Boolean uniqueFlag) {
		this.uniqueFlag = uniqueFlag;
	}

	public Boolean getMustFillFlag() {
		return mustFillFlag;
	}

	public void setMustFillFlag(Boolean mustFillFlag) {
		this.mustFillFlag = mustFillFlag;
	}

	public String getReferCode() {
		return referCode;
	}

	public void setReferCode(String referCode) {
		this.referCode = referCode;
	}

	public String getDefdocCode() {
		return defdocCode;
	}

	public void setDefdocCode(String defdocCode) {
		this.defdocCode = defdocCode;
	}

	public Boolean getQueryConditionFlag() {
		return queryConditionFlag;
	}

	public void setQueryConditionFlag(Boolean queryConditionFlag) {
		this.queryConditionFlag = queryConditionFlag;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

}

==> ejc-mdm-api-3.0.0-20250328.004026-193-sources.jar: com/ejianc/foundation/mdm/vo/DataModelItemVO.java <==
package com.ejianc.foundation.mdm.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 数据模型字段表
 * 
 * @author guoming
 *
 */
public class DataModelItemVO extends BaseVO {

	private static final long serialVersionUID = 1L;

	/**
	 * 数据模型ID
	 */
	private Long dataModelId;
	/**
	 * 模型字段编码
	 */
	private String itemCode;
	/**
	 * 模型字段名称
	 */
	private String itemName;
	/**
	 * 数据类型
	 */
	private String dataType;
	/**
	 * 数据长度
	 */
	private Integer dataLength;
	/**
	 * 小数位
	 */
	private Integer decimalPlace;
	/**
	 * 是否唯一： 0不唯一，1：唯一
	 */
	private Boolean uniqueFlag;
	/**
	 * 是否必填：0不必填 ，1必填
	 */
	private Boolean mustFillFlag;

	/**
	 * 参照编码
	 */
	private String referCode;

	/**
	 * 枚举档案编码
	 */
	private String defdocCode;
	/**
	 * 是否作为查询条件：0不作为，1作为查询条件
	 */
	private Boolean queryConditionFlag;
	/**
	 * 排序字段
	 */
	private Integer sequence;

	/**
	 * 描述信息
	 */
	private String description;

	/**
	 * 排序
	 */
	private String sortValue;

	public Long getDataModelId() {
		return dataModelId;
	}

	public void setDataModelId(Long dataModelId) {
		this.dataModelId = dataModelId;
	}

	public String getItemCode() {
		return itemCode;
	}

	public void setItemCode(String itemCode) {
		this.itemCode = itemCode;
	}

	public String getItemName() {
		return itemName;
	}

	public void setItemName(String itemName) {
		this.itemName = itemName;
	}

	public String getDataType() {
		return dataType;
	}

	public void setDataType(String dataType) {
		this.dataType = dataType;
	}

	public Integer getDataLength() {
		return dataLength;
	}

	public void setDataLength(Integer dataLength) {
		this.dataLength = dataLength;
	}

	public Integer getDecimalPlace() {
		return decimalPlace;
	}

	public void setDecimalPlace(Integer decimalPlace) {
		this.decimalPlace = decimalPlace;
	}

	public Boolean getUniqueFlag() {
		return uniqueFlag;
	}

	public void setUniqueFlag(Boolean uniqueFlag) {
		this.uniqueFlag = uniqueFlag;
	}

	public Boolean getMustFillFlag() {
		return mustFillFlag;
	}

	public void setMustFillFlag(Boolean mustFillFlag) {
		this.mustFillFlag = mustFillFlag;
	}

	public String getReferCode() {
		return referCode;
	}

	public void setReferCode(String referCode) {
		this.referCode = referCode;
	}

	public String getDefdocCode() {
		return defdocCode;
	}

	public void setDefdocCode(String defdocCode) {
		this.defdocCode = defdocCode;
	}

	public Boolean getQueryConditionFlag() {
		return queryConditionFlag;
	}

	public void setQueryConditionFlag(Boolean queryConditionFlag) {
		this.queryConditionFlag = queryConditionFlag;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public String getSortValue() {
		return sortValue;
	}

	public void setSortValue(String sortValue) {
		this.sortValue = sortValue;
	}

}
